@@ -25,7 +25,7 @@ use Date::Manip::Base;
 use Data::Dumper;
 
 our $VERSION;
-$VERSION='6.54';
+$VERSION='6.56';
 END { undef $VERSION; }
 
 # To get rid of a 'used only once' warnings.
@@ -424,9 +424,12 @@ sub _get_curr_zone {
          }
          my $var = shift(@methods);
          print "$var] "  if ($debug);
-         if (defined $$::var) {
-            push(@zone,$$::var);
-            print "$$::var\n"  if ($debug);
+         no strict "refs";
+         my $val = ${ "::$var" };
+         use strict "refs";
+         if (defined $val) {
+            push(@zone,$val);
+            print "$val\n"  if ($debug);
          } else {
             print "undef\n"  if ($debug);
          }
